@@ -4,8 +4,8 @@
 #' repository and saves it to the specified path. If the file already exists,
 #' the user is prompted before it is replaced.
 #'
-#' @param path The file path where the SQLite database should be saved. If not
-#'   provided, the default path is "data/tidy_finance_r.sqlite".
+#' @param path The file path where the SQLite database should be saved.
+#' @param url The URL where the SQLite database is stored.
 #'
 #' @returns Invisible `NULL`. Side effect: downloads a file to the specified path.
 #'
@@ -13,7 +13,12 @@
 #' @examples
 #' path <- paste0(tempdir(), "/tidy_finance_r.sqlite")
 #' create_wrds_dummy_database(path)
-create_wrds_dummy_database <- function(path) {
+create_wrds_dummy_database <- function(
+  path, url = paste0(
+    "https://github.com/tidy-finance/website/tree/main/blog/",
+    "tidy-finance-dummy-data/data/tidy_finance.sqlite"
+  )
+) {
 
   if (missing(path)) {
     cli::cli_abort(c(
@@ -30,14 +35,17 @@ create_wrds_dummy_database <- function(path) {
     }
   }
 
-  url <- "https://github.com/tidy-finance/website/tree/main/blog/tidy-finance-dummy-data/data/tidy_finance.sqlite"
-  utils::download.file(
-    url = url,
-    destfile = path,
-    quiet = TRUE
+  handle_download_error(
+    function() suppressWarnings(utils::download.file(
+      url = url,
+      destfile = path,
+      quiet = TRUE
+    ))
   )
 
-  cli::cli_inform("Downloaded WRDS dummy database to {.path {path}}.")
+  if (file.exists(path)) {
+    cli::cli_inform("Downloaded WRDS dummy database to {.path {path}}.")
+  }
 
   invisible(NULL)
 }
