@@ -21,17 +21,12 @@
 #'   osap_monthly <- download_data_osap(start_date = "2020-01-01", end_date = "2020-06-30")
 #' }
 download_data_osap <- function(
-    start_date = NULL, end_date = NULL, sheet_id = "1JyhcF5PRKHcputlioxlu5j5GyLo4JYyY"
-  ) {
+  start_date = NULL, end_date = NULL, sheet_id = "1JyhcF5PRKHcputlioxlu5j5GyLo4JYyY"
+) {
 
-  if (is.null(start_date) || is.null(end_date)) {
-    cli::cli_inform(
-      "No {.arg start_date} or {.arg end_date} provided. Returning the full data set."
-    )
-  } else {
-    start_date <- as.Date(start_date)
-    end_date <- as.Date(end_date)
-  }
+  dates <- validate_dates(start_date, end_date)
+  start_date <- dates$start_date
+  end_date <- dates$end_date
 
   url <- paste0("https://drive.google.com/uc?export=download&id=", sheet_id)
 
@@ -50,15 +45,6 @@ download_data_osap <- function(
   processed_data <- raw_data |>
     mutate(date = ymd(date))
 
-  to_snake_case <- function(x) {
-    x <- gsub("([a-z])([A-Z])", "\\1_\\2", x)
-    x <- gsub("[^[:alnum:]_]+", "_", x)
-    x <- tolower(x)
-    x <- gsub("_+", "_", x)
-    x <- gsub("^_|_$", "", x)
-    return(x)
-  }
-
   colnames(processed_data) <- to_snake_case(colnames(processed_data))
 
   if (!is.null(start_date) && !is.null(end_date)) {
@@ -68,3 +54,12 @@ download_data_osap <- function(
 
   return(processed_data)
 }
+
+to_snake_case <- function(x) {
+  x <- gsub("([a-z])([A-Z])", "\\1_\\2", x)
+  x <- gsub("[^[:alnum:]_]+", "_", x)
+  x <- tolower(x)
+  x <- gsub("_+", "_", x)
+  x <- gsub("^_|_$", "", x)
+  return(x)
+}
